@@ -25,7 +25,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '0.04'; # from Piper-0.04.tar.gz
+our $VERSION = '0.05'; # from Piper-0.05.tar.gz
 
 #pod =head1 ATTRIBUTES
 #pod
@@ -777,7 +777,7 @@ sub pressure {
         return max(map { $_->pressure } @{$self->children});
     }
     else {
-        return $self->pending ? int(100 * $self->pending / $self->batch_size) : 0;
+        return $self->pending ? (int(100 * $self->pending / $self->batch_size) || 1) : 0;
     }
 }
 
@@ -1089,7 +1089,7 @@ It first attempts to choose the full-batch segment (C<< pending >= batch_size >>
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
